@@ -1,6 +1,7 @@
 from . import utils
 from . import soup
-from ..core import errors
+from .errors import log_and_swallow_error
+from ..core.errors import OpenTrainingError
 from ..core.topic import Topic
 from ..core.group import Group
 from ..core.errors import OpenTrainingError
@@ -37,9 +38,8 @@ def _ev_doctree_read__extract_groupnodes(app, doctree):
                 userdata=n,
             ))
             n.replace_self([])
-    except Exception:
-        _logger.exception(f'{docname}: cannot extract group nodes')
-        raise
+    except OpenTrainingError as e:
+        log_and_swallow_error(e, _logger)
 
 class _GroupNode(nodes.Element):
     def __init__(self, path):
